@@ -11,7 +11,7 @@
    Class declaration for a sample output driver with no additional attributes
    and methods (minimal interface)
 
-   Copyright (C) 1993 - 2014 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2023 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ class drvRIB : public drvbase {
 public:
 
 	derivedConstructor(drvRIB);
-	~drvRIB(); 
+	~drvRIB() override; 
 	
 	class DriverOptions : public ProgramOptions {
 	public:
